@@ -75,13 +75,16 @@ create_logout_widget (void)
 	GtkWidget *button;
 	char *pixmap_name;
 
-	pixmap_name = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
-						 "gnome-term-night.png", TRUE, NULL);
+	pixmap_name = panel_pixmap_discovery ("gnome-term-night.png",
+					      TRUE /* fallback */);
 
 	button = button_widget_new (pixmap_name, -1,
 				    FALSE,
 				    PANEL_ORIENT_UP,
 				    _("Log out"));
+	g_free (pixmap_name);
+	if (!button)
+		return NULL;
 
 	/*A hack since this function only pretends to work on window
 	  widgets (which we actually kind of are) this will select
@@ -99,7 +102,6 @@ create_logout_widget (void)
 			    G_CALLBACK (drag_data_get_cb),
 			    "LOGOUT");
 
-	g_free (pixmap_name);
 	gtk_tooltips_set_tip (panel_tooltips, button, _("Log out of GNOME"), NULL);
 
 	g_signal_connect (G_OBJECT (button), "clicked",
@@ -129,11 +131,11 @@ load_logout_applet (PanelWidget *panel,
 	if (!info)
 		return;
 
-	panel_applet_add_callback (info, "help", GTK_STOCK_HELP, _("Help"));
+	panel_applet_add_callback (info, "help", GTK_STOCK_HELP, _("_Help"));
 }
 
 static GtkWidget *
-create_lock_widget(void)
+create_lock_widget (void)
 {
         static GtkTargetEntry dnd_targets[] = {
 		{ "application/x-panel-applet-internal", 0, 0 }
@@ -141,14 +143,16 @@ create_lock_widget(void)
 	GtkWidget *button;
 	char *pixmap_name;
 
-	pixmap_name = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
-						 "gnome-lockscreen.png",
-						 TRUE, NULL);
+	pixmap_name = panel_pixmap_discovery ("gnome-lockscreen.png",
+					      TRUE /* fallback */);
 
 	button = button_widget_new (pixmap_name, -1,
 				    FALSE,
 				    PANEL_ORIENT_UP,
 				    _("Lock screen"));
+	g_free (pixmap_name);
+	if (!button)
+		return NULL;
 
 	/*A hack since this function only pretends to work on window
 	  widgets (which we actually kind of are) this will select
@@ -166,11 +170,10 @@ create_lock_widget(void)
 			    G_CALLBACK (drag_data_get_cb),
 			    "LOCK");
 
-	g_free (pixmap_name);
 	gtk_tooltips_set_tip (panel_tooltips, button, _("Lock screen"), NULL);
 
-	g_signal_connect (G_OBJECT (button), "clicked",
-			    G_CALLBACK (panel_lock), NULL);
+	g_signal_connect (button, "clicked",
+			  G_CALLBACK (panel_lock), NULL);
 
 	return button;
 }
@@ -187,7 +190,6 @@ load_lock_applet (PanelWidget *panel,
 	g_return_if_fail (panel != NULL);
 
 	lock = create_lock_widget ();
-
 	if (!lock)
 		return;
 
@@ -208,13 +210,13 @@ load_lock_applet (PanelWidget *panel,
 	  <jwz> and "xscreensaver-demo"
 	*/
 
-	panel_applet_add_callback (info, "activate", NULL, _("Activate Screensaver"));
-	panel_applet_add_callback (info, "lock", NULL, _("Lock Screen"));
-	panel_applet_add_callback (info, "exit", NULL, _("Kill Screensaver Daemon"));
-	panel_applet_add_callback (info, "restart", NULL, _("Restart Screensaver Daemon"));
+	panel_applet_add_callback (info, "activate", NULL, _("_Activate Screensaver"));
+	panel_applet_add_callback (info, "lock", NULL, _("_Lock Screen"));
+	panel_applet_add_callback (info, "exit", NULL, _("_Kill Screensaver Daemon"));
+	panel_applet_add_callback (info, "restart", NULL, _("Restart _Screensaver Daemon"));
 
 	if (!commie_mode)
-		panel_applet_add_callback (info, "prefs", NULL, _("Properties"));
+		panel_applet_add_callback (info, "prefs", NULL, _("_Properties"));
 
-	panel_applet_add_callback (info, "help", GTK_STOCK_HELP, _("Help"));
+	panel_applet_add_callback (info, "help", GTK_STOCK_HELP, _("_Help"));
 }
